@@ -147,7 +147,7 @@ xfce_mixer_class_init (XfceMixerClass *klass)
 static void
 xfce_mixer_instance_init (XfceMixer *mixer)
 {
-  mixer->widgets = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
+  mixer->widgets = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
   mixer->message_handler_id = 0;
 }
 
@@ -161,7 +161,7 @@ xfce_mixer_constructed (GObject *object)
   XfceMixerTrackType    type;
   GstMixerTrack        *track;
   const GList          *iter;
-  const gchar          *titles[4] = { _("Playback"), _("Capture"), _("Switches"), _("Options") };
+  const gchar          *titles[4] = { N_("Playback"), N_("Capture"), N_("Switches"), N_("Options") };
   GtkWidget            *track_widget;
   GtkWidget            *labels[4];
   GtkWidget            *scrollwins[4];
@@ -170,15 +170,18 @@ xfce_mixer_constructed (GObject *object)
   GtkWidget            *label1;
   GtkWidget            *label2;
   GList                *visible_controls;
+  gchar                *label;
   guint                 num_children[4] = { 0, 0, 0, 0 };
   gint                  i;
 
+  g_hash_table_remove_all (mixer->widgets);
+
   preferences = xfce_mixer_preferences_get ();
 
   /* Create widgets for all four tabs */
   for (i = 0; i < 4; ++i)
     {
-      labels[i] = gtk_label_new (titles[i]);
+      labels[i] = gtk_label_new (_(titles[i]));
       scrollwins[i] = gtk_scrolled_window_new (NULL, NULL);
       gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwins[i]), GTK_SHADOW_IN);
       gtk_container_set_border_width (GTK_CONTAINER (scrollwins[i]), 6);
@@ -188,6 +191,7 @@ xfce_mixer_constructed (GObject *object)
         {
           views[i] = gtk_table_new (1, 1, FALSE);
           gtk_table_set_col_spacings (GTK_TABLE (views[i]), 12);
+          gtk_table_set_row_spacings (GTK_TABLE (views[i]), 6);
         }
       else
         views[i] = gtk_vbox_new (FALSE, 6);
@@ -210,6 +214,8 @@ xfce_mixer_constructed (GObject *object)
       /* Determine the type of the mixer track */
       type = xfce_mixer_track_type_new (track);
 
+      g_object_get (GST_MIXER_TRACK (track), "label", &label, NULL);
+
       switch (type) 
         {
         case XFCE_MIXER_TRACK_TYPE_PLAYBACK:
@@ -228,7 +234,7 @@ xfce_mixer_constructed (GObject *object)
           num_children[0]++;
 
           /* Add the track to the hash table */
-          g_hash_table_insert (mixer->widgets, track->label, track_widget);
+          g_hash_table_insert (mixer->widgets, g_strdup (label), track_widget);
           break;
 
         case XFCE_MIXER_TRACK_TYPE_CAPTURE:
@@ -247,7 +253,7 @@ xfce_mixer_constructed (GObject *object)
           num_children[1]++;
 
           /* Add the track to the hash table */
-          g_hash_table_insert (mixer->widgets, track->label, track_widget);
+          g_hash_table_insert (mixer->widgets, g_strdup (label), track_widget);
           break;
 
         case XFCE_MIXER_TRACK_TYPE_SWITCH:
@@ -257,7 +263,7 @@ xfce_mixer_constructed (GObject *object)
           num_children[2]++;
 
           /* Add the track to the hash table */
-          g_hash_table_insert (mixer->widgets, track->label, track_widget);
+          g_hash_table_insert (mixer->widgets, g_strdup (label), track_widget);
           break;
 
         case XFCE_MIXER_TRACK_TYPE_OPTIONS:
@@ -267,9 +273,11 @@ xfce_mixer_constructed (GObject *object)
           num_children[3]++;
 
           /* Add the track to the hash table */
-          g_hash_table_insert (mixer->widgets, track->label, track_widget);
+          g_hash_table_insert (mixer->widgets, g_strdup (label), track_widget);
           break;
         }
+
+      g_free (label);
     }
 
   /* Append tab or destroy all its widgets - depending on the contents of each tab */
@@ -389,7 +397,7 @@ xfce_mixer_new (GstElement *card)
 
 #ifdef HAVE_GST_MIXER_NOTIFICATION
 static void
-xfce_mixer_bus_message (GstBus *bus,
+xfce_mixer_bus_message (GstBus     *bus,
                         GstMessage *message,
                         XfceMixer  *mixer)
 {
@@ -400,6 +408,7 @@ xfce_mixer_bus_message (GstBus *bus,
   gboolean            muted;
   gboolean            record;
   const gchar        *option;
+  gchar              *label;
   gint               *volumes;
   gint                num_channels;
 
@@ -413,9 +422,10 @@ xfce_mixer_bus_message (GstBus *bus,
   if (type == GST_MIXER_MESSAGE_MUTE_TOGGLED)
     {
       gst_mixer_message_parse_mute_toggled (message, &track, &muted);
-      DBG ("Track '%s' was %s", track->label, muted ? "muted" : "unmuted");
-  
-      widget = g_hash_table_lookup (mixer->widgets, track->label);
+      g_object_get (track, "label", &label, NULL);
+      DBG ("Track '%s' was %s", label, muted ? "muted" : "unmuted");
+      widget = g_hash_table_lookup (mixer->widgets, label);
+      g_free (label);
 
       if (IS_XFCE_MIXER_TRACK (widget))
         xfce_mixer_track_update_mute (XFCE_MIXER_TRACK (widget));
@@ -425,9 +435,10 @@ xfce_mixer_bus_message (GstBus *bus,
   else if (type == GST_MIXER_MESSAGE_RECORD_TOGGLED)
     {
       gst_mixer_message_parse_record_toggled (message, &track, &record);
-      DBG ("Recording on track '%s' was %s", track->label, record ? "turned on" : "turned off");
-
-      widget = g_hash_table_lookup (mixer->widgets, track->label);
+      g_object_get (track, "label", &label, NULL);
+      DBG ("Recording on track '%s' was %s", label, record ? "turned on" : "turned off");
+      widget = g_hash_table_lookup (mixer->widgets, label);
+      g_free (label);
 
       if (IS_XFCE_MIXER_TRACK (widget))
         xfce_mixer_track_update_record (XFCE_MIXER_TRACK (widget));
@@ -437,9 +448,10 @@ xfce_mixer_bus_message (GstBus *bus,
   else if (type == GST_MIXER_MESSAGE_VOLUME_CHANGED)
     {
       gst_mixer_message_parse_volume_changed (message, &track, &volumes, &num_channels);
-      DBG ("Volume on track '%s' changed to %i", track->label, volumes[0]);
-
-      widget = g_hash_table_lookup (mixer->widgets, track->label);
+      g_object_get (track, "label", &label, NULL);
+      DBG ("Volume on track '%s' changed to %i", label, volumes[0]);
+      widget = g_hash_table_lookup (mixer->widgets, label);
+      g_free (label);
 
       if (IS_XFCE_MIXER_TRACK (widget))
         xfce_mixer_track_update_volume (XFCE_MIXER_TRACK (widget));
@@ -447,9 +459,10 @@ xfce_mixer_bus_message (GstBus *bus,
   else if (type == GST_MIXER_MESSAGE_OPTION_CHANGED)
     {
       gst_mixer_message_parse_option_changed (message, &options, &option);
-      DBG ("Option '%s' was set to '%s'", GST_MIXER_TRACK (options)->label, option);
-
-      widget = g_hash_table_lookup (mixer->widgets, GST_MIXER_TRACK (options)->label);
+      g_object_get (GST_MIXER_TRACK (options), "label", &label, NULL);
+      DBG ("Option '%s' was set to '%s'", label, option);
+      widget = g_hash_table_lookup (mixer->widgets, label);
+      g_free (label);
 
       if (IS_XFCE_MIXER_OPTION (widget))
         xfce_mixer_option_update (XFCE_MIXER_OPTION (widget));
